@@ -11,8 +11,22 @@ class ErrorCreatingSession(OTRSClientException):
 
 
 class TicketNotCreated(OTRSClientException):
-    def __init__(self, error_msg):
-        message = "Error creating the ticket with the next error message: {}".format(error_msg)
+
+    def _DF_to_string(self, df_list):
+        if not df_list or len(df_list) == 0:
+            return ""
+        df_msg = ""
+        for df in df_list:
+            df_msg = df_msg + "{}: {}\n".format(df.name, df.value)
+        return df_msg
+
+    def __init__(self, error_msg, dynamic_fields=None):
+
+        title_message = "Error creating the ticket with the next error message:"
+        df_message = self._DF_to_string(dynamic_fields)
+
+        message = "{}\n\t{}\n{}".format(title_message, error_msg, df_message)
+
         super(OTRSClientException, self).__init__(message)
 
 
