@@ -1,5 +1,6 @@
 class CustomerData:
-    def __init__(self, id, vat_number, phone, name, first_name, street, city, zip, subdivision):
+    def __init__(self, id, vat_number, phone, name, first_name, street,
+                 city, zip, subdivision, has_active_contracts, language):
         self.id = id
         self.vat_number = vat_number
         self.phone = phone
@@ -9,3 +10,5 @@ class CustomerData:
         self.city = city
         self.zip = zip
         self.subdivision = subdivision
+        self.has_active_contracts = has_active_contracts
+        self.language = language
