@@ -12,15 +12,12 @@ class FiberDynamicFields(InternetDynamicFields):
         return [
             self._df_previous_contract_pon(),
             self._df_previous_contract_fiber_speed(),
-            self._activation_notes(),
             self._df_mobile_pack_contracts(),
             self._all_grouped_SIMS_recieved(),
             self._df_has_previous_owner_with_mobile_pack_contracts(),
+            self._has_documentation()
         ]
 
-    def _activation_notes(self):
-        return DynamicField(name="consideracionsActivacio2", value=self.service_data.activation_notes)
-
     def _df_previous_contract_pon(self):
         return DynamicField(name="ponAntic", value=self.service_data.previous_contract_pon)
 
@@ -50,3 +47,9 @@ class FiberDynamicFields(InternetDynamicFields):
             name="flagDNItitularAnteriorMobils",
             value=has_grouped_mobile_with_previous_owner,
         )
+
+    def _has_documentation(self):
+        return DynamicField(
+            name="flagDocumentacio",
+            value="0"
+        )
