@@ -1,5 +1,5 @@
 # coding: utf-8
-from otrs_somconnexio.otrs_models.configurations.fiber_ticket import FiberTicketConfiguration
+from otrs_somconnexio.otrs_models.configurations.provision.fiber_ticket import FiberTicketConfiguration
 from otrs_somconnexio.otrs_models.fiber_dynamic_fields import FiberDynamicFields
 from otrs_somconnexio.otrs_models.provision_ticket import ProvisionTicket
 
