@@ -21,12 +21,12 @@ class MobileDynamicFields(ProvisionDynamicFields):
             self._sim_received(),
             self._sim_delivery_tracking_code(),
             self._send_sim_type(),
-            self._activation_notes(),
             self._delivery_street(),
             self._delivery_zip_code(),
             self._delivery_city(),
             self._delivery_state(),
             self._fiber_linked(),
+            self._has_documentation()
         ]
 
     def _order_id(self):
@@ -59,12 +59,6 @@ class MobileDynamicFields(ProvisionDynamicFields):
             value=self.service_data.previous_owner_vat
         )
 
-    def _activation_notes(self):
-        return DynamicField(
-            name="consideracionsActivacio",
-            value=self.service_data.activation_notes
-        )
-
     def _sim_received(self):
         sim_recieved = "1" if self.service_data.has_sim else "0"
         return DynamicField("SIMrebuda", sim_recieved)
@@ -113,3 +107,9 @@ class MobileDynamicFields(ProvisionDynamicFields):
             name="OdooContractRefRelacionat",
             value=self.service_data.fiber_linked
         )
+
+    def _has_documentation(self):
+        return DynamicField(
+            name="flagDocumentacio",
+            value="0"
+        )
