@@ -29,7 +29,6 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'has_sim',
             'sim_delivery_tracking_code',
             'is_grouped_with_fiber',
-            'activation_notes',
             'delivery_street',
             'delivery_city',
             'delivery_zip_code',
@@ -66,7 +65,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
         ).build()
         ticket.create()
 
-        self.assertEquals(ticket.id, 234)
+        self.assertEqual(ticket.id, 234)
         self.assertIsInstance(ticket, MobileTicket)
 
     @patch('otrs_somconnexio.otrs_models.provision_ticket.OTRSClient')
@@ -89,7 +88,6 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'has_sim',
             'sim_delivery_tracking_code',
             'is_grouped_with_fiber',
-            'activation_notes',
             'delivery_street',
             'delivery_city',
             'delivery_zip_code',
@@ -128,7 +126,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
         ).build()
         ticket.create()
 
-        self.assertEquals(ticket.id, 234)
+        self.assertEqual(ticket.id, 234)
         self.assertIsInstance(ticket, MobilePausedTicket)
 
     @patch('otrs_somconnexio.otrs_models.provision_ticket.OTRSClient')
@@ -151,7 +149,6 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'has_sim',
             'sim_delivery_tracking_code',
             'is_grouped_with_fiber',
-            'activation_notes',
             'delivery_street',
             'delivery_city',
             'delivery_zip_code',
@@ -189,7 +186,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
         ).build()
         ticket.create()
 
-        self.assertEquals(ticket.id, 234)
+        self.assertEqual(ticket.id, 234)
         self.assertIsInstance(ticket, MobilePausedTicket)
 
     @patch('otrs_somconnexio.otrs_models.provision_ticket.OTRSClient')
@@ -258,7 +255,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
         ticket.create()
 
         self.assertIsInstance(ticket, ADSLTicket)
-        self.assertEquals(ticket.id, 234)
+        self.assertEqual(ticket.id, 234)
 
     @patch('otrs_somconnexio.otrs_models.provision_ticket.OTRSClient')
     def test_create_fiber_ticket_factory(self, MockOTRSClient):
@@ -288,7 +285,6 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
                 "shipment_zip",
                 "shipment_subdivision",
                 "notes",
-                "activation_notes",
                 "adsl_coverage",
                 "mm_fiber_coverage",
                 "vdf_fiber_coverage",
@@ -322,4 +318,4 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
         ticket.create()
 
         self.assertIsInstance(ticket, FiberTicket)
-        self.assertEquals(ticket.id, 234)
+        self.assertEqual(ticket.id, 234)
