@@ -53,7 +53,6 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
                 "previous_owner_name",
                 "previous_owner_surname",
                 "notes",
-                "activation_notes",
                 "adsl_coverage",
                 "mm_fiber_coverage",
                 "vdf_fiber_coverage",
@@ -604,21 +603,6 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["proveidorPreviCU"], "SC-MM")
 
-    def test_activation_notes_field(self):
-        self.service_data.activation_notes = "text text text"
-
-        dynamic_fields = FiberDynamicFields(
-            self.service_data,
-            self.customer_data,
-            self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id,
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(
-            dynamic_fields_dct["consideracionsActivacio2"], "text text text"
-        )
-
     def test_mobile_pack_contracts_field(self):
         self.service_data.mobile_pack_contracts = "3456,12345"
 
@@ -699,3 +683,14 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["TecDelServei"], "Fibra")
+
+    def test_documentation(self):
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id,
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["flagDocumentacio"], "0")
