@@ -52,7 +52,6 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             'delivery_city',
             'delivery_zip_code',
             'delivery_state',
-            'activation_notes',
             'technology',
             'fiber_linked',
         ])
@@ -488,19 +487,6 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["provinciaEnviament"], "ES-A")
 
-    def test_activation_notes_field(self):
-        self.mobile_data.activation_notes = "text text text"
-
-        dynamic_fields = MobileDynamicFields(
-            self.mobile_data,
-            self.customer_data,
-            self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["consideracionsActivacio"], "text text text")
-
     def test_tecnhology(self):
         self.mobile_data.technology = "Mòbil"
 
@@ -540,3 +526,14 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["CorreusTrackingCode"], "72")
+
+    def test_documentation(self):
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["flagDocumentacio"], "0")
\ No newline at end of file
