@@ -33,7 +33,8 @@ class UnblockMobilePackTicketTestCase(unittest.TestCase):
             0
         )
 
-        UnblockMobilePackTicket(ticket_number, "2022-11-11").run()
+        UnblockMobilePackTicket(ticket_number, activation_date="2022-11-11",
+                                introduced_date="2022-11-09").run()
 
         MockOTRSClient.return_value.get_ticket_by_number.assert_called_once_with(
             ticket_number,
@@ -74,7 +75,8 @@ class UnblockMobilePackTicketTestCase(unittest.TestCase):
             1
         )
 
-        UnblockMobilePackTicket(ticket_number, "2022-11-11").run()
+        UnblockMobilePackTicket(ticket_number, activation_date="2022-11-11",
+                                introduced_date="2022-11-09").run()
 
         MockOTRSClient.return_value.get_ticket_by_number.assert_called_once_with(
             ticket_number,
@@ -84,7 +86,7 @@ class UnblockMobilePackTicketTestCase(unittest.TestCase):
         MockOTRSClient.return_value.update_ticket.assert_called_once_with(
             MockOTRSClient.return_value.get_ticket_by_number.return_value.tid,
             article=None,
-            dynamic_fields=[ANY, ANY],
+            dynamic_fields=[ANY, ANY, ANY],
         )
         MockDF.assert_has_calls(
             [
@@ -93,9 +95,13 @@ class UnblockMobilePackTicketTestCase(unittest.TestCase):
                     value=1,
                 ),
                 call(
-                    name="dataIntroPlataforma",
+                    name="dataActivacioLiniaMobil",
                     value="2022-11-11",
                 ),
+                call(
+                    name="dataIntroPlataforma",
+                    value="2022-11-09",
+                ),
             ],
             any_order=True,
         )
